NLSL: eprmat.f90 File Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

Modules | Variables
eprmat.f90 File Reference

Go to the source code of this file.

## Modules
module | eprmat

## Variables
double precision, dimension(mxel), save | eprmat::zmat
double precision, dimension(2, mxdim), save | eprmat::zdiag
integer, dimension(mxel), save | eprmat::izmat
integer, dimension(mxdim+1), save | eprmat::jzmat
integer, dimension(mxdim+1), save | eprmat::kzmat